Class: Aws::LicenseManagerUserSubscriptions::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::LicenseManagerUserSubscriptions::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-licensemanagerusersubscriptions/client.rb,
sig/client.rbs
Overview
An API client for LicenseManagerUserSubscriptions. To construct a client, you need to configure a :region and :credentials.
client = Aws::LicenseManagerUserSubscriptions::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateUserResponseSuccess, _CreateLicenseServerEndpointResponseSuccess, _DeleteLicenseServerEndpointResponseSuccess, _DeregisterIdentityProviderResponseSuccess, _DisassociateUserResponseSuccess, _ListIdentityProvidersResponseSuccess, _ListInstancesResponseSuccess, _ListLicenseServerEndpointsResponseSuccess, _ListProductSubscriptionsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListUserAssociationsResponseSuccess, _RegisterIdentityProviderResponseSuccess, _StartProductSubscriptionResponseSuccess, _StopProductSubscriptionResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateIdentityProviderSettingsResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_user(params = {}) ⇒ Types::AssociateUserResponse
Associates the user to an EC2 instance to utilize user-based subscriptions.
-
#create_license_server_endpoint(params = {}) ⇒ Types::CreateLicenseServerEndpointResponse
Creates a network endpoint for the Remote Desktop Services (RDS) license server.
-
#delete_license_server_endpoint(params = {}) ⇒ Types::DeleteLicenseServerEndpointResponse
Deletes a
LicenseServerEndpointresource. -
#deregister_identity_provider(params = {}) ⇒ Types::DeregisterIdentityProviderResponse
Deregisters the Active Directory identity provider from License Manager user-based subscriptions.
-
#disassociate_user(params = {}) ⇒ Types::DisassociateUserResponse
Disassociates the user from an EC2 instance providing user-based subscriptions.
-
#list_identity_providers(params = {}) ⇒ Types::ListIdentityProvidersResponse
Lists the Active Directory identity providers for user-based subscriptions.
-
#list_instances(params = {}) ⇒ Types::ListInstancesResponse
Lists the EC2 instances providing user-based subscriptions.
-
#list_license_server_endpoints(params = {}) ⇒ Types::ListLicenseServerEndpointsResponse
List the Remote Desktop Services (RDS) License Server endpoints.
-
#list_product_subscriptions(params = {}) ⇒ Types::ListProductSubscriptionsResponse
Lists the user-based subscription products available from an identity provider.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns the list of tags for the specified resource.
-
#list_user_associations(params = {}) ⇒ Types::ListUserAssociationsResponse
Lists user associations for an identity provider.
-
#register_identity_provider(params = {}) ⇒ Types::RegisterIdentityProviderResponse
Registers an identity provider for user-based subscriptions.
-
#start_product_subscription(params = {}) ⇒ Types::StartProductSubscriptionResponse
Starts a product subscription for a user with the specified identity provider.
-
#stop_product_subscription(params = {}) ⇒ Types::StopProductSubscriptionResponse
Stops a product subscription for a user with the specified identity provider.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_identity_provider_settings(params = {}) ⇒ Types::UpdateIdentityProviderSettingsResponse
Updates additional product configuration settings for the registered identity provider.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1737 1738 1739 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 1737 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1740 1741 1742 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 1740 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_user(params = {}) ⇒ Types::AssociateUserResponse
Associates the user to an EC2 instance to utilize user-based subscriptions.
86 |
# File 'sig/client.rbs', line 86
def associate_user: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 1710 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::LicenseManagerUserSubscriptions') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-licensemanagerusersubscriptions' context[:gem_version] = '1.53.0' Seahorse::Client::Request.new(handlers, context) end |
#create_license_server_endpoint(params = {}) ⇒ Types::CreateLicenseServerEndpointResponse
Creates a network endpoint for the Remote Desktop Services (RDS) license server.
101 |
# File 'sig/client.rbs', line 101
def create_license_server_endpoint: (
|
#delete_license_server_endpoint(params = {}) ⇒ Types::DeleteLicenseServerEndpointResponse
Deletes a LicenseServerEndpoint resource.
124 |
# File 'sig/client.rbs', line 124
def delete_license_server_endpoint: (
|
#deregister_identity_provider(params = {}) ⇒ Types::DeregisterIdentityProviderResponse
Deregisters the Active Directory identity provider from License Manager user-based subscriptions.
135 |
# File 'sig/client.rbs', line 135
def deregister_identity_provider: (
|
#disassociate_user(params = {}) ⇒ Types::DisassociateUserResponse
Disassociates the user from an EC2 instance providing user-based subscriptions.
147 |
# File 'sig/client.rbs', line 147
def disassociate_user: (
|
#list_identity_providers(params = {}) ⇒ Types::ListIdentityProvidersResponse
Lists the Active Directory identity providers for user-based subscriptions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
162 |
# File 'sig/client.rbs', line 162
def list_identity_providers: (
|
#list_instances(params = {}) ⇒ Types::ListInstancesResponse
Lists the EC2 instances providing user-based subscriptions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
181 |
# File 'sig/client.rbs', line 181
def list_instances: (
|
#list_license_server_endpoints(params = {}) ⇒ Types::ListLicenseServerEndpointsResponse
List the Remote Desktop Services (RDS) License Server endpoints
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
200 |
# File 'sig/client.rbs', line 200
def list_license_server_endpoints: (
|
#list_product_subscriptions(params = {}) ⇒ Types::ListProductSubscriptionsResponse
Lists the user-based subscription products available from an identity provider.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
219 |
# File 'sig/client.rbs', line 219
def list_product_subscriptions: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns the list of tags for the specified resource.
239 |
# File 'sig/client.rbs', line 239
def list_tags_for_resource: (
|
#list_user_associations(params = {}) ⇒ Types::ListUserAssociationsResponse
Lists user associations for an identity provider.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
250 |
# File 'sig/client.rbs', line 250
def list_user_associations: (
|
#register_identity_provider(params = {}) ⇒ Types::RegisterIdentityProviderResponse
Registers an identity provider for user-based subscriptions.
270 |
# File 'sig/client.rbs', line 270
def register_identity_provider: (
|
#start_product_subscription(params = {}) ⇒ Types::StartProductSubscriptionResponse
Starts a product subscription for a user with the specified identity provider.
286 |
# File 'sig/client.rbs', line 286
def start_product_subscription: (
|
#stop_product_subscription(params = {}) ⇒ Types::StopProductSubscriptionResponse
Stops a product subscription for a user with the specified identity provider.
300 |
# File 'sig/client.rbs', line 300
def stop_product_subscription: (
|
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
313 |
# File 'sig/client.rbs', line 313
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
323 |
# File 'sig/client.rbs', line 323
def untag_resource: (
|
#update_identity_provider_settings(params = {}) ⇒ Types::UpdateIdentityProviderSettingsResponse
Updates additional product configuration settings for the registered identity provider.
334 |
# File 'sig/client.rbs', line 334
def update_identity_provider_settings: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1730 1731 1732 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 1730 def waiter_names [] end |