Class: Aws::LicenseManagerUserSubscriptions::Types::ProductUserSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::LicenseManagerUserSubscriptions::Types::ProductUserSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-licensemanagerusersubscriptions/types.rb
Overview
A summary of the user-based subscription products for a specific user.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain ⇒ String
The domain name of the Active Directory that contains the user information for the product subscription.
-
#identity_provider ⇒ Types::IdentityProvider
An object that specifies details for the identity provider.
-
#license_expiration_date ⇒ String
The expiration date of the license associated with this subscription, in ISO 8601 UTC format (for example,
2025-03-15T00:00:00Z). -
#product ⇒ String
The name of the user-based subscription product.
-
#product_user_arn ⇒ String
The Amazon Resource Name (ARN) for this product user.
-
#status ⇒ String
The status of a product for this user.
-
#status_message ⇒ String
The status message for a product for this user.
-
#subscription_end_date ⇒ String
The end date of a subscription.
-
#subscription_start_date ⇒ String
The start date of a subscription.
-
#username ⇒ String
The user name from the identity provider for this product user.
Instance Attribute Details
#domain ⇒ String
The domain name of the Active Directory that contains the user information for the product subscription.
1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/types.rb', line 1036 class ProductUserSummary < Struct.new( :username, :product, :identity_provider, :status, :product_user_arn, :status_message, :domain, :subscription_start_date, :subscription_end_date, :license_expiration_date) SENSITIVE = [] include Aws::Structure end |
#identity_provider ⇒ Types::IdentityProvider
An object that specifies details for the identity provider.
1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/types.rb', line 1036 class ProductUserSummary < Struct.new( :username, :product, :identity_provider, :status, :product_user_arn, :status_message, :domain, :subscription_start_date, :subscription_end_date, :license_expiration_date) SENSITIVE = [] include Aws::Structure end |
#license_expiration_date ⇒ String
The expiration date of the license associated with this
subscription, in ISO 8601 UTC format (for example,
2025-03-15T00:00:00Z).
This field applies only to subscriptions that use license server
endpoints, such as Remote Desktop Services (RDS) Subscriber Access
License (SAL). It returns null for products that don't use
license-based subscriptions.
1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/types.rb', line 1036 class ProductUserSummary < Struct.new( :username, :product, :identity_provider, :status, :product_user_arn, :status_message, :domain, :subscription_start_date, :subscription_end_date, :license_expiration_date) SENSITIVE = [] include Aws::Structure end |
#product ⇒ String
The name of the user-based subscription product.
1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/types.rb', line 1036 class ProductUserSummary < Struct.new( :username, :product, :identity_provider, :status, :product_user_arn, :status_message, :domain, :subscription_start_date, :subscription_end_date, :license_expiration_date) SENSITIVE = [] include Aws::Structure end |
#product_user_arn ⇒ String
The Amazon Resource Name (ARN) for this product user.
1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/types.rb', line 1036 class ProductUserSummary < Struct.new( :username, :product, :identity_provider, :status, :product_user_arn, :status_message, :domain, :subscription_start_date, :subscription_end_date, :license_expiration_date) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of a product for this user.
1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/types.rb', line 1036 class ProductUserSummary < Struct.new( :username, :product, :identity_provider, :status, :product_user_arn, :status_message, :domain, :subscription_start_date, :subscription_end_date, :license_expiration_date) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
The status message for a product for this user.
1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/types.rb', line 1036 class ProductUserSummary < Struct.new( :username, :product, :identity_provider, :status, :product_user_arn, :status_message, :domain, :subscription_start_date, :subscription_end_date, :license_expiration_date) SENSITIVE = [] include Aws::Structure end |
#subscription_end_date ⇒ String
The end date of a subscription.
1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/types.rb', line 1036 class ProductUserSummary < Struct.new( :username, :product, :identity_provider, :status, :product_user_arn, :status_message, :domain, :subscription_start_date, :subscription_end_date, :license_expiration_date) SENSITIVE = [] include Aws::Structure end |
#subscription_start_date ⇒ String
The start date of a subscription.
1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/types.rb', line 1036 class ProductUserSummary < Struct.new( :username, :product, :identity_provider, :status, :product_user_arn, :status_message, :domain, :subscription_start_date, :subscription_end_date, :license_expiration_date) SENSITIVE = [] include Aws::Structure end |
#username ⇒ String
The user name from the identity provider for this product user.
1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/types.rb', line 1036 class ProductUserSummary < Struct.new( :username, :product, :identity_provider, :status, :product_user_arn, :status_message, :domain, :subscription_start_date, :subscription_end_date, :license_expiration_date) SENSITIVE = [] include Aws::Structure end |