Class: Aws::LicenseManagerUserSubscriptions::Types::ServerSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::LicenseManagerUserSubscriptions::Types::ServerSettings
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-licensemanagerusersubscriptions/types.rb
Overview
Note:
ServerSettings is a union - when making an API calls you must set exactly one of the members.
Contains settings for a specific server.
Defined Under Namespace
Classes: RdsSalSettings, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#rds_sal_settings ⇒ Types::RdsSalSettings
The
RdsSalSettingsresource contains settings to configure a specific Remote Desktop Services (RDS) license server. -
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#rds_sal_settings ⇒ Types::RdsSalSettings
The RdsSalSettings resource contains settings to configure a
specific Remote Desktop Services (RDS) license server.
1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/types.rb', line 1166 class ServerSettings < Struct.new( :rds_sal_settings, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RdsSalSettings < ServerSettings; end class Unknown < ServerSettings; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1166 1167 1168 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/types.rb', line 1166 def unknown @unknown end |