Class: Aws::LicenseManagerUserSubscriptions::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::LicenseManagerUserSubscriptions::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-licensemanagerusersubscriptions/client.rb
Overview
An API client for LicenseManagerUserSubscriptions. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::LicenseManagerUserSubscriptions::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_user(params = {}) ⇒ Types::AssociateUserResponse
Associates the user to an EC2 instance to utilize user-based subscriptions.
-
#create_license_server_endpoint(params = {}) ⇒ Types::CreateLicenseServerEndpointResponse
Creates a network endpoint for the Remote Desktop Services (RDS) license server.
-
#delete_license_server_endpoint(params = {}) ⇒ Types::DeleteLicenseServerEndpointResponse
Deletes a ‘LicenseServerEndpoint` resource.
-
#deregister_identity_provider(params = {}) ⇒ Types::DeregisterIdentityProviderResponse
Deregisters the Active Directory identity provider from License Manager user-based subscriptions.
-
#disassociate_user(params = {}) ⇒ Types::DisassociateUserResponse
Disassociates the user from an EC2 instance providing user-based subscriptions.
-
#list_identity_providers(params = {}) ⇒ Types::ListIdentityProvidersResponse
Lists the Active Directory identity providers for user-based subscriptions.
-
#list_instances(params = {}) ⇒ Types::ListInstancesResponse
Lists the EC2 instances providing user-based subscriptions.
-
#list_license_server_endpoints(params = {}) ⇒ Types::ListLicenseServerEndpointsResponse
List the Remote Desktop Services (RDS) License Server endpoints.
-
#list_product_subscriptions(params = {}) ⇒ Types::ListProductSubscriptionsResponse
Lists the user-based subscription products available from an identity provider.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns the list of tags for the specified resource.
-
#list_user_associations(params = {}) ⇒ Types::ListUserAssociationsResponse
Lists user associations for an identity provider.
-
#register_identity_provider(params = {}) ⇒ Types::RegisterIdentityProviderResponse
Registers an identity provider for user-based subscriptions.
-
#start_product_subscription(params = {}) ⇒ Types::StartProductSubscriptionResponse
Starts a product subscription for a user with the specified identity provider.
-
#stop_product_subscription(params = {}) ⇒ Types::StopProductSubscriptionResponse
Stops a product subscription for a user with the specified identity provider.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_identity_provider_settings(params = {}) ⇒ Types::UpdateIdentityProviderSettingsResponse
Updates additional product configuration settings for the registered identity provider.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1737 1738 1739 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 1737 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1740 1741 1742 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 1740 def errors_module Errors end |
Instance Method Details
#associate_user(params = {}) ⇒ Types::AssociateUserResponse
Associates the user to an EC2 instance to utilize user-based subscriptions.
<note markdown=“1”> Your estimated bill for charges on the number of users and related costs will take 48 hours to appear for billing periods that haven’t closed (marked as Pending billing status) in Amazon Web Services Billing. For more information, see [Viewing your monthly charges] in the *Amazon Web Services Billing User Guide*.
</note>
[1]: docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/invoice.html
569 570 571 572 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 569 def associate_user(params = {}, = {}) req = build_request(:associate_user, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 1710 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::LicenseManagerUserSubscriptions') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-licensemanagerusersubscriptions' context[:gem_version] = '1.51.0' Seahorse::Client::Request.new(handlers, context) end |
#create_license_server_endpoint(params = {}) ⇒ Types::CreateLicenseServerEndpointResponse
Creates a network endpoint for the Remote Desktop Services (RDS) license server.
628 629 630 631 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 628 def create_license_server_endpoint(params = {}, = {}) req = build_request(:create_license_server_endpoint, params) req.send_request() end |
#delete_license_server_endpoint(params = {}) ⇒ Types::DeleteLicenseServerEndpointResponse
Deletes a ‘LicenseServerEndpoint` resource.
673 674 675 676 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 673 def delete_license_server_endpoint(params = {}, = {}) req = build_request(:delete_license_server_endpoint, params) req.send_request() end |
#deregister_identity_provider(params = {}) ⇒ Types::DeregisterIdentityProviderResponse
Deregisters the Active Directory identity provider from License Manager user-based subscriptions.
753 754 755 756 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 753 def deregister_identity_provider(params = {}, = {}) req = build_request(:deregister_identity_provider, params) req.send_request() end |
#disassociate_user(params = {}) ⇒ Types::DisassociateUserResponse
Disassociates the user from an EC2 instance providing user-based subscriptions.
839 840 841 842 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 839 def disassociate_user(params = {}, = {}) req = build_request(:disassociate_user, params) req.send_request() end |
#list_identity_providers(params = {}) ⇒ Types::ListIdentityProvidersResponse
Lists the Active Directory identity providers for user-based subscriptions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
910 911 912 913 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 910 def list_identity_providers(params = {}, = {}) req = build_request(:list_identity_providers, params) req.send_request() end |
#list_instances(params = {}) ⇒ Types::ListInstancesResponse
Lists the EC2 instances providing user-based subscriptions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
979 980 981 982 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 979 def list_instances(params = {}, = {}) req = build_request(:list_instances, params) req.send_request() end |
#list_license_server_endpoints(params = {}) ⇒ Types::ListLicenseServerEndpointsResponse
List the Remote Desktop Services (RDS) License Server endpoints
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1043 1044 1045 1046 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 1043 def list_license_server_endpoints(params = {}, = {}) req = build_request(:list_license_server_endpoints, params) req.send_request() end |
#list_product_subscriptions(params = {}) ⇒ Types::ListProductSubscriptionsResponse
Lists the user-based subscription products available from an identity provider.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1147 1148 1149 1150 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 1147 def list_product_subscriptions(params = {}, = {}) req = build_request(:list_product_subscriptions, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns the list of tags for the specified resource.
1177 1178 1179 1180 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 1177 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_user_associations(params = {}) ⇒ Types::ListUserAssociationsResponse
Lists user associations for an identity provider.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1276 1277 1278 1279 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 1276 def list_user_associations(params = {}, = {}) req = build_request(:list_user_associations, params) req.send_request() end |
#register_identity_provider(params = {}) ⇒ Types::RegisterIdentityProviderResponse
Registers an identity provider for user-based subscriptions.
1364 1365 1366 1367 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 1364 def register_identity_provider(params = {}, = {}) req = build_request(:register_identity_provider, params) req.send_request() end |
#start_product_subscription(params = {}) ⇒ Types::StartProductSubscriptionResponse
Starts a product subscription for a user with the specified identity provider.
<note markdown=“1”> Your estimated bill for charges on the number of users and related costs will take 48 hours to appear for billing periods that haven’t closed (marked as Pending billing status) in Amazon Web Services Billing. For more information, see [Viewing your monthly charges] in the *Amazon Web Services Billing User Guide*.
</note>
[1]: docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/invoice.html
1465 1466 1467 1468 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 1465 def start_product_subscription(params = {}, = {}) req = build_request(:start_product_subscription, params) req.send_request() end |
#stop_product_subscription(params = {}) ⇒ Types::StopProductSubscriptionResponse
Stops a product subscription for a user with the specified identity provider.
1552 1553 1554 1555 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 1552 def stop_product_subscription(params = {}, = {}) req = build_request(:stop_product_subscription, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
1580 1581 1582 1583 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 1580 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
1607 1608 1609 1610 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 1607 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_identity_provider_settings(params = {}) ⇒ Types::UpdateIdentityProviderSettingsResponse
Updates additional product configuration settings for the registered identity provider.
1701 1702 1703 1704 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 1701 def update_identity_provider_settings(params = {}, = {}) req = build_request(:update_identity_provider_settings, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1730 1731 1732 |
# File 'lib/aws-sdk-licensemanagerusersubscriptions/client.rb', line 1730 def waiter_names [] end |